@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::Biblio::Dumper;
 # ABSTRACT: Class dumping a Koha Catalog
-$Koha::Contrib::Tamil::Biblio::Dumper::VERSION = '0.038';
+$Koha::Contrib::Tamil::Biblio::Dumper::VERSION = '0.039';
 use Moose;
 
 extends 'AnyEvent::Processor';
@@ -126,7 +126,7 @@ override 'process' => sub {
     # Specific conversion
     $record = $self->convert->($record);
 
-    $self->writer->write($record);
+    $self->writer->write($record) if $record;
     return super();
 };
 
@@ -169,7 +169,7 @@ Koha::Contrib::Tamil::Biblio::Dumper - Class dumping a Koha Catalog
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
